Changelog for websauna.viewconfig
=================================

0.1.2 (2016-01-29)
------------------

- Fixed ``@view_overrides`` overriding a parent class with another ``@view_overrides``


0.1.1 (unreleased)
------------------

- Fix extra debug print

